ProgressModel class

Constructors

ProgressModel({String status = '', double uploadPercentage = 0.0, int currentChunkIndex = 0, int totalChunks = 0, int chunksUploaded = 0, bool isCompleted = false})

Properties

chunksUploaded ↔ int
The number of chunks that have been successfully uploaded.
getter/setter pair
currentChunkIndex ↔ int
The index of the chunk currently being uploaded.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isCompleted ↔ bool
Indicates if the upload has been completed successfully.
getter/setter pair
onError ↔ ErrorCallback?
Callback function for error updates
getter/setter pair
onProgress ↔ ProgressCallback?
Callback function for progress updates
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String
The current status of the upload process (e.g., uploading, paused, completed).
getter/setter pair
totalChunks ↔ int
The total number of chunks to be uploaded.
getter/setter pair
uploadPercentage ↔ double
The percentage of upload completion (0.0 to 100.0).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited