VideoUploadState class

A class representing the state of video upload operation.

Constructors

VideoUploadState({String? signedUrl, Timer? timer, File? video, List<File>? chunks, List? chunksSignedUrls, int chunkSize = 5 * 1024 * 1024, String? uploadId, String? objectName, bool isPaused = false, int? pausedChunkIndex})
Creates an instance of VideoUploadState.

Properties

chunks List<File>
A list of video chunks generated from the original video file.
final
chunkSize int
The size of each chunk in bytes. Defaults to 5 MB.
getter/setter pair
chunksSignedUrls List
A list of signed URLs for each chunk of the video.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isPaused bool
Indicates whether the upload is paused.
getter/setter pair
objectName String?
The name of the object being uploaded.
getter/setter pair
pausedChunkIndex int?
The index of the chunk where the upload was paused, if any.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signedUrl String?
The signed URL for uploading the video.
getter/setter pair
timer Timer?
The timer used for checking internet connectivity or other periodic tasks.
getter/setter pair
uploadId String?
The unique identifier for the upload session.
getter/setter pair
video File?
The video file to be uploaded.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited