ProgressModel class
A class representing the progress and status of a video upload operation.
Constructors
Properties
- chunks ↔ int
-
The number of chunks into which the video has been split.
getter/setter pair
- chunksUploaded ↔ int
-
The number of chunks that have been uploaded so far.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCompleted ↔ bool
-
Indicates whether the upload process is completed.
getter/setter pair
- lastChunk ↔ int?
-
The index of the last chunk being processed, if any.
getter/setter pair
- onError ↔ Function?
-
A callback function that is invoked to report errors.
getter/setter pair
- onProgress ↔ Function?
-
A callback function that is invoked to report progress updates.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signedUrls ↔ int
-
The number of signed URLs obtained for video chunks.
getter/setter pair
- status ↔ String
-
The current status of the upload process.
getter/setter pair
- uploadPercentage ↔ double
-
The percentage of the video upload that has been completed.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
progressStream
→ Stream<
ProgressModel> -
no setter
Static Methods
-
dispose(
) → void - Closes the progress stream.
-
updateProgress(
ProgressModel progress) → void - Adds a new ProgressModel to the stream.