ProgressModel constructor
ProgressModel({})
Creates an instance of ProgressModel.
chunks - The number of chunks into which the video has been split.
signedUrls - The number of signed URLs obtained for video chunks.
uploadPercentage - The percentage of the video upload that has been completed.
chunksUploaded - The number of chunks that have been uploaded so far.
lastChunk - The index of the last chunk being processed, if any.
isCompleted - Indicates whether the upload process is completed.
status - The current status of the upload process.
onProgress - A callback function for progress updates.
onError - A callback function for error reporting.
Implementation
ProgressModel({
this.chunks = 0,
this.signedUrls = 0,
this.uploadPercentage = 0,
this.chunksUploaded = 0,
this.lastChunk,
this.isCompleted = false,
this.status = 'Ready',
this.onProgress,
this.onError,
});