services/video_upload_service library
Classes
- FlutterResumableUploads
- A model representing the progress of an upload operation.
Enums
- UploadStatus
- Enum to represent the status of the upload process
Typedefs
- ErrorCallback = void Function(UploadError error)
- Type alias for error callback
- ProgressCallback = void Function(ProgressModel progress)
- Type alias for progress callback