FlutterResumableUploads class
A model representing the progress of an upload operation.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
internetStream
→ Stream<
bool> -
no setter
- progressModel → ProgressModel
-
no setter
Static Methods
-
cancelTimer(
) → void -
checkInternetConnection(
) → void -
pauseUpload(
) → void -
resumeUpload(
) → void -
uploadVideo(
{required File file, required String signedUrl, int? chunkSize, ProgressCallback? onProgress, ErrorCallback? onError}) → Future< void> - Parameters:
Constants
- API_ERROR_CODE → const int
- CONNECTIVITY_ERROR_CODE → const int
- FILE_ERROR_CODE → const int
- GENERAL_ERROR_CODE → const int
- NETWORK_ERROR_CODE → const int