ApiConstants class
A class containing API endpoint constants for video upload operations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- completeUploadUrl → const String
- The URL used to complete the multipart upload process.
- multipartUploadsUrl → const String
- The URL used to get signed URLs for multipart uploads.
- platform → const MethodChannel
- videoUploadsUrl → const String
- The URL used to get the signed URL for video uploads.